#! /bin/sh
#
# setconfigReaderServerOp			1.0 98/03/18
#
# Script to be used from setReaderServerOp() method in ReaderServerOpImpl.java
#
# author: Geetha Srikantan
#
#
#     Exit value         Status
#     ----------         ------
#         0              success
#         1              exit value from SetCCReaderServerOp
#         2              exit value from SetCCReaderServerOp
#         4              News server process id does not exist OR
#                        server process is not running
#         5              shlock fails in this script - no operations performed
#         6              environment setup error in script
#


echo "In setconfigReaderServerOp: at start"

search_path() {
  for d in `echo $PATH | tr ':' ' '`
  do
     if [ -f $d/$1 -a -x $d/$1 ]
     then
        echo $d
	exit 6
     fi
  done
}


error() {
  echo "Error: $1" 2>&1
  exit 6
}




if [ -z "$JAVA_HOME" ]
then
  d=`search_path java`
  if [ -n "$d" ]
  then
    JAVA_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$JAVA_HOME" ]
  then
    JAVA_HOME=/opt/java
  fi
fi

if [ ! -x "$JAVA_HOME/bin/java" ]
then 
  error "Cannot find Java runtime"
fi


if [ -z "$ISP_HOME" ]
then
  d=`dirname $0`
  if [ -n "$d" ]
  then 
    ISP_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$ISP_HOME" ]
  then
    error "Cannot find default for ISP_HOME"
  fi
fi


echo $JAVA_HOME
echo $ISP_HOME

if [ ! -d "$ISP_HOME" ]
then 
  error "Invalid setting for ISP_HOME"
fi


ARCH=`uname -p`


export CLASSPATH
CLASSPATH=$JAVA_HOME/lib/classes.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/classes:$CLASSPATH
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/jndi.jar:$ISP_HOME/lib/ldap.jar
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/providerutil.jar
CLASSPATH=$ISP_HOME/lib/newsadmin.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/lib/ispadmin.zip:$CLASSPATH
CLASSPATH=/opt/SUNWcorba/lib/JavaIDL/classes.zip:$CLASSPATH

#export LD_LIBRARY_PATH
#LD_LIBRARY_PATH=$JAVA_HOME/lib:$ISP_HOME/lib/solaris/$ARCH:$LD_LIBRARY_PATH

cd $ISP_HOME


# Try to set file descriptors to max, fail silently if necessary
ulimit -S -n `ulimit -H -n` 2 >&1 > /dev/null



# Lock the necessary files
#

LOCK=/etc/opt/SUNWixsna/admin/state/lock.newsadmin
trap 'rm -f ${LOCK} ; exit 1' 1 2 3 15
if /opt/SUNWsns/bin/shlock -f ${LOCK} -p $$ ; then

  echo "In setconfigReaderServerOp: after locking"
  

  # Check if file exists..
  #
  if [ -f /var/news/rstate/snsd.pid ] ; then

    # Allow edits only if process is running..
    #

    kill -0 `cat /var/news/rstate/snsd.pid`
    if [ $? = 0 ] ; then

      # Change permissions on files that will be written to
      #
      chmod u+w /var/news/rconfig/sns.conf

      # Process is running, call java program to save config parameters and 
      # store into specified file
      #
  
      /usr/java/bin/java com.sun.newsadmin.server.SetCCReaderServerOp $* 
      outSetCCReaderServerOp=$?


      # Change permissions back on file
      #
      
      chmod u-w /var/news/rconfig/sns.conf
      
      
      # Need to send signal to snsd to load new parameter values
      #
      if [ $outSetCCReaderServerOp = 0 ] ; then
	kill -HUP `cat /var/news/rstate/snsd.pid`
      else
	echo "Problem executing SetCCReaderServerOp"
	exit $outSetCCReaderServerOp
      fi

    else 

      # Process is not running..
      #

      exit 4
    fi

  else
    
    # File does not exist..fail again
    #

    exit 4

  fi


else 
  echo Fails: Locked by `cat ${LOCK}`
  exit 5
fi
