#! /bin/sh
#
# setconfigReaderSetup			1.0 98/03/18
#
# Script to be used from doReaderSetup() method in ReaderSetupImpl.java
#
# author: Geetha Srikantan
#
#
#     Exit value         Status
#     ----------         ------
#         0              success
#         1              Exit value 1 from SetCCReaderSetup
#         2              Exit value 2 from SetCCReaderSetup
#         3              Exit value 3 from SetCCReaderSetup
#         4              Exit value 4 from SetCCReaderSetup
#         5              shlock fails in this script - no operations performed
#         6              environment setup error in script
#         7              Setup_News non-zero exit value
#         8              Could not start server
#         9              News server setup done, no more changes allowed.
#
# NOTE: Setup_News may exit with non-zero values which overlap
# with some of the exit status mentioned above.
#

SAFE_NEWS_ADMIN_CONFIG=/etc/opt/SUNWixsna/admin/tmp/safe.newsadmconfig
NEWS_ADMIN_CONFIG=/etc/opt/SUNWixsna/admin/state/newsadmconfig

echo "In setconfigReaderSetup: at start"

search_path() {
  for d in `echo $PATH | tr ':' ' '`
  do
     if [ -f $d/$1 -a -x $d/$1 ]
     then
        echo $d
	exit 6
     fi
  done
}


error() {
  echo "Error: $1" 2>&1
  exit 6
}




if [ -z "$JAVA_HOME" ]
then
  d=`search_path java`
  if [ -n "$d" ]
  then
    JAVA_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$JAVA_HOME" ]
  then
    JAVA_HOME=/opt/java
  fi
fi

if [ ! -x "$JAVA_HOME/bin/java" ]
then 
  error "Cannot find Java runtime"
fi


if [ -z "$ISP_HOME" ]
then
  d=`dirname $0`
  if [ -n "$d" ]
  then 
    ISP_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$ISP_HOME" ]
  then
    error "Cannot find default for ISP_HOME"
  fi
fi


echo $JAVA_HOME
echo $ISP_HOME

if [ ! -d "$ISP_HOME" ]
then 
  error "Invalid setting for ISP_HOME"
fi


ARCH=`uname -p`


export CLASSPATH
CLASSPATH=$JAVA_HOME/lib/classes.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/classes:$CLASSPATH
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/jndi.jar:$ISP_HOME/lib/ldap.jar
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/providerutil.jar
CLASSPATH=$ISP_HOME/lib/newsadmin.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/lib/ispadmin.zip:$CLASSPATH
CLASSPATH=/opt/SUNWcorba/lib/JavaIDL/classes.zip:$CLASSPATH

#export LD_LIBRARY_PATH
#LD_LIBRARY_PATH=$JAVA_HOME/lib:$ISP_HOME/lib/solaris/$ARCH:$LD_LIBRARY_PATH

cd $ISP_HOME


# Try to set file descriptors to max, fail silently if necessary
ulimit -S -n `ulimit -H -n` 2 >&1 > /dev/null



# Lock the necessary files
#

LOCK=/etc/opt/SUNWixsna/admin/state/lock.newsadmin
trap 'rm -f ${LOCK} ; exit 1' 1 2 3 15
if /opt/SUNWsns/bin/shlock -f ${LOCK} -p $$ ; then

	echo "In setconfigReaderSetup: after locking"

	# Call java program to update config parameters in the
	# relevant config files. 

	# The 1st argument is a filename. The Java program will write
	# data to this file, which is to be used as input to the
	# Setup_News script. 
	
	setup_input=$1
	/opt/SUNWsns/bin/setup/is_setup > /dev/null 2>&1
	setupDone=$?
	echo "setupDone is " $setupDone

	# Change permissions on admin config files to allow edits
	#
	chmod u+w $NEWS_ADMIN_CONFIG

	# If server has not been setup before, do so now; 
	# else exit with error status - changes disallowed.
	#

	if [ $setupDone -eq 1 ] ; then 
	  /usr/java/bin/java com.sun.newsadmin.server.SetCCReaderSetup $* setupDone:$setupDone
	  # Save exit value for parsing
	  #
	  outSetCCReaderSetup=$?
	else 
	  echo "Reader server has been setup, cannot change parameters!"
	  exit 9
	fi


	# Check exit value from Java program
	#

	if [ $outSetCCReaderSetup -ne 0 ] ; then
	  # Undo edits to config files
	  cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG
	  chmod u-w $NEWS_ADMIN_CONFIG
	  exit $outSetCCReaderSetup
	fi

	# Continue on, if exit value from java program was 0
	#

	echo "In setconfigReaderSetup: after calling java class"


	# Call Setup_News script for reader
	/opt/SUNWsns/bin/Setup_News < $setup_input
	opStatus=$?
	echo "opStatus is: " $opStatus
	serverStatus=0
	if [ $opStatus -eq 0 ] ; then
	  /etc/init.d/news.server start
	  serverStatus=$?
	fi
	echo "serverStatus is: " $serverStatus

	if [ $opStatus -ne 0 ] ; then
	  echo "Failed execution of Setup_News"
	  # Undo edits to config files
	  cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG
	  chmod u-w $NEWS_ADMIN_CONFIG
	  exit 7 
	fi
	
	if [ $serverStatus -ne 0 ] ; then
	  echo "Failed execution of news.server"
	  # Undo edits to config files
	  cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG
	  chmod u-w $NEWS_ADMIN_CONFIG
	  exit 8 
	fi

	chmod u-w $NEWS_ADMIN_CONFIG
	exit 0

else
	echo Fails: Locked by `cat ${LOCK}`
	exit 5
fi
